@@ -5,8 +5,8 @@ from Quartz.PDFKit import *
 class TestPDFAnnotationPopup (TestCase):
     @min_os_level('10.5')
     def testMethods(self):
-        self.failUnlessResultIsBOOL(PDFAnnotationPopup.isOpen)
-        self.failUnlessArgIsBOOL(PDFAnnotationPopup.setIsOpen_, 0)
+        self.assertResultIsBOOL(PDFAnnotationPopup.isOpen)
+        self.assertArgIsBOOL(PDFAnnotationPopup.setIsOpen_, 0)
 
 if __name__ == "__main__":
     main()
