@@ -4,7 +4,7 @@ from Quartz.QuartzCore import *
 
 class TestCIFilterShape (TestCase):
     def testMethods(self):
-        self.failUnlessArgIsBOOL(CIFilterShape.transformBy_interior_, 1)
+        self.assertArgIsBOOL(CIFilterShape.transformBy_interior_, 1)
 
 if __name__ == "__main__":
     main()
