@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from Quartz.QuartzCore import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestCIRAWFilter (TestCase):
     @min_os_level('10.5')
     def testConstants10_5(self):
