@@ -2,6 +2,16 @@
 from PyObjCTools.TestSupport import *
 from Quartz import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
 class TestCVPixelFormatDescription (TestCase):
     def testConstants(self):
         self.assertIsInstance(kCVPixelFormatName, unicode)
@@ -50,6 +60,10 @@ class TestCVPixelFormatDescription (TestCase):
     def testConstants10_6(self):
         self.assertIsInstance(kCVPixelFormatBlackBlock, unicode)
 
+    @min_os_level('10.7')
+    def testConstants10_7(self):
+        self.assertIsInstance(kCVPixelFormatContainsAlpha, unicode)
+
 
 
 if __name__ == "__main__":
